@@ -59,7 +59,7 @@ print.ols_correlations <- function(x, ...) {
 #' @importFrom purrr map_df
 cordata <- function(model) {
 
-  avplots_data(model)
+  ols_prep_avplot_data(model)
 
 }
 
@@ -90,7 +90,7 @@ corsign <- function(model) {
     use_series(coefficients) %>%
     `[`(, 1) %>%
     extract(-1) %>%
-    sign()
+    sign(.)
 
 }
 
