@@ -11,4 +11,7 @@
 NULL
 
 ## quiets concerns of R CMD check re: the .'s that appear in pipelines
-if(getRversion() >= "2.15.1")  utils::globalVariables(c("."))
\ No newline at end of file
+if (getRversion() >= "2.15.1") {
+  utils::globalVariables(c(".", "owner", "repo", "tag_name"
+  ))
+}
