@@ -13,7 +13,7 @@
   behind_cran <- cran_version > local_version
 
   tips <- c(
-    "Learn more about olsrr at http://github.com/rsquaredacademy/olsrr/.",
+    "Learn more about olsrr at https://github.com/rsquaredacademy/olsrr/.",
     "Use suppressPackageStartupMessages() to eliminate package startup messages.",
     "Need help getting started with regression models? Visit: https://www.rsquaredacademy.com",
     "Check out our interactive app for quick data exploration. Visit: https://apps.rsquaredacademy.com/."
