@@ -17,9 +17,10 @@ library(caret)
 library(lubridate)
 library(scales)
 library(stringr)
+library(inferr)
 
 shinyServer(function(input, output, session) {
-    
+
     source("logic/logic_dataoptions.R", local = T)
     source("logic/logic_upload.R", local = T)
     source("logic/logic_transform2.R", local = T)
@@ -38,6 +39,7 @@ shinyServer(function(input, output, session) {
     source("logic/logic_mfit2.R", local = T)
     source("logic/logic_regdiag.R", local = T)
     source("logic/logic_home.R", local = T)
+    source("logic/logic_exit_button.R", local = T)
 })
 
 
