@@ -10,21 +10,21 @@ library(goftest)
 
 ## ----qqresid, fig.width=5, fig.height=5, fig.align='center'--------------
 model <- lm(mpg ~ disp + hp + wt + qsec, data = mtcars)
-ols_rsd_qqplot(model)
+ols_plot_resid_qq(model)
 
 ## ----normtest------------------------------------------------------------
 model <- lm(mpg ~ disp + hp + wt + qsec, data = mtcars)
-ols_norm_test(model)
+ols_test_normality(model)
 
 ## ----corrtest------------------------------------------------------------
 model <- lm(mpg ~ disp + hp + wt + qsec, data = mtcars)
-ols_corr_test(model)
+ols_test_correlation(model)
 
 ## ----rvsfplot, fig.width=5, fig.height=5, fig.align='center'-------------
 model <- lm(mpg ~ disp + hp + wt + qsec, data = mtcars)
-ols_rvsp_plot(model)
+ols_plot_resid_fit(model)
 
 ## ----residhist, fig.width=5, fig.height=5, fig.align='center'------------
 model <- lm(mpg ~ disp + hp + wt + qsec, data = mtcars)
-ols_rsd_hist(model)
+ols_plot_resid_hist(model)
 
