@@ -13,17 +13,6 @@ test_that("all subsets selection output matches the expected result", {
   expect_equivalent(k$predictors, pred_exp)
 })
 
-test_that("all_subsets fails when model inherits other than 'lm'", {
-  y <- sample(c(1:4), 100, replace = T)
-  x <- sample(c(1, 2), 100, replace = T)
-  m <- glm(x ~ y)
-  expect_error(ols_step_all_possible(m), "Please specify a OLS linear regression model.")
-})
-
-test_that("all_subsets returns an error when number of predictors < 2", {
-  model <- lm(y ~ x1, data = cement)
-  expect_error(ols_step_all_possible(model), "Please specify a model with at least 2 predictors.")
-})
 
 test_that("output from all subsets regression is as expected", {
   x <- cat("# A tibble: 3 x 6
